
************************************************************************************************************************;
********************************************** Sample program code Stata ***********************************************;
 
*** Note: The sample program code serves as an orientation for writing your program code. The objective is to        ***;
*** generate an output file that is helping the output check for confidentiality in the best possible way.           ***;
*** Please note: This sample program code does not provide statistic-specific support on the processing and          ***;
*** analysis of your requested data.                                                                                 ***;
                                                                                                                    
************************************************************************************************************************;

clear all

*** Set version
version <13> /*Insert version*/

*** Control monitor output
set more off
set logtype text
set linesize 255 

*** Set path of ado
sysdir set PERSONAL "<Path is added at the Research Data Centre>"
mata mata mlib index

*** Macros for paths
global datapath "<Path is added at the Research Data Centre>\"
global outputpath "<Path is added at the Research Data Centre>\"

*** Macros for names of dataset and output
global dataname <dataname.dta> /*Insert name of the dataset*/
global outputname <outputname>   /*Insert name of the output*/


********************************************************************************************************************
*** Start record log.
capture log close
log using "$outputpath\$outputname.log", replace


********************************************************************************************************************
********************************************************************************************************************
********************************************************************************************************************


************************************************************************************************************************;
************************************************************************************************************************;
*** Project title:			<Women and employment in Germany>       
*** Data base:		 		<Microcensus 2012>
***
*** Name of program code:	<name_program_code.do> 
*** created: 				<Date> 
*** by: 					<Name> 
*** E-mail: 				<E-mail-address> 
*** Phone: 					<phone number> 
*** 
*** Name of output file: 	<outputname.log>
*** 
*** 
*** Outline of the program: 
***			<Program code for the examination of multiple person data sets (Check of the data base), 
***			 descriptive analyses> 
*** 
***
*** Used variables: 
*** Original variables: 
***    <EF1:   		Federal state 
*** 	EF2:   		Administrative district 
*** 	EF3S:  		Number of selected district 
*** 	EF4S:  		Serial number of household in selected district 
*** 	EF5S:  		Serial number of person in the household
*** 	EF25:  		Serial number of familiy in the household
*** 	EF30:  		Population at primary residence
*** 	EF31:  		Population in private households
*** 	EF44:  		Age
*** 	EF46:  		Sex
*** 	EF49:  		Marital status
*** 	EF310: 		Highest qualification
*** 	EF952: 		Standard projection factor year>
***
*** 
*** Variables newly created in this program code <name_program_code.do>: 
***    <marr:       dichotomous variable married yes/no
***     persnr:  	Number of person
*** 	famnr:   	Number of familiy 
*** 	hhnr:    	Number of household 
*** 	nrdiff:  	Difference number of household - number of family
*** 	piddiff: 	Test unique number of person>
***
*** Note: If you use variables that were created in a previous program code, please list them in a separate block. 
***
*** Variable projection factor: EF952
***
***
************************************************************************************************************************;
************************************************************************************************************************;



********************************************************************************************************************
*** I. Data processing
********************************************************************************************************************


*** a. Input dataset
*** Direct selection of necessary variables (memory space- and runtime-efficient).

*** Population in private households (EF31 = 1) at the place of permanent residence (EF30 < 3)

use EF1 - EF5s EF25 EF30 EF31 EF44 EF46 EF49 EF310 EF952 ///
using $datapath\$dataname if EF31 == 1 &  EF30 < 3, clear


*** b. Generation dichotomous variable marr which shows if a person is married. 

recode EF49 (2 = 1) (1 3 4 5 6 7 = 0), gen (marr)


*** c. Generation number of household and family from EF1, EF2, EF3S, EF4S, EF5S, EF25
*** persnr: EF1 to EF5s
*** hhnr: EF1 to EF4s
*** famnr: EF1 to EF4s + EF25

generate double persnr=(EF1*10000000000) + (EF2*1000000000) + (EF3s*100000) + (EF4s*1000) + (EF5s*10)
generate double hhnr=(EF1*10000000000) + (EF2*1000000000) + (EF3s*100000) + (EF4s*1000) + 1
generate double famnr=(EF1*10000000000) + (EF2*1000000000) + (EF3s*100000) + (EF4s*1000) + (EF25*1)
format %13.0g persnr hhnr famnr


*** d. Preparation test: number of household different from number of family
*** If number of family (famnr) is different then number of household (hhnr)
*** then difference number of household (hhnr) - number of family (nrdiff) equals 1

generate nrdiff = 0

replace nrdiff = 1 if famnr ~= hhnr


*** e. Preparation test: multiple number of person
*** If number of person (persnr) equals that of the predecessor
*** then test unique number of person (piddiff) equals 1 

sort persnr

generate piddiff = 0
replace piddiff = 1 if persnr == persnr[_n-1]


*** f. Labeling of variables and values

label variable marr     "Married"

label variable hhnr 	"Number of household"
label variable famnr 	"Number of family"
label variable persnr 	"Number of person"

label variable piddiff 	"Test unique number of person"
label variable nrdiff 	"Difference number of household - number of family"

label define marr       1 "yes" ///
                        0 "no"
label values marr marr
						
label define nrdiff 	1 "Number of household and number of family different" ///
						0 "Number of household and number of family identical"
label values nrdiff nrdiff

label define piddiff 	1 "Number of person multiple" ///
						0 "Number of person unique"
label values piddiff piddiff



********************************************************************************************************************
*** II. Data analysis
********************************************************************************************************************

*** For every produced result it has to be stated if it is to be checked for confidentiality or if it is produced 
*** solely for the purpose of the RDC output checking process. This declaration can be made as a general comment 
*** like "All produced results are needed." or "Only weighted results are needed.", as long as the wording is 
*** unambiguous.

*** Output No. 1: Number of household different from number of family

tabulate nrdiff


*** Output No. 2: Test multiple number of person

tabulate piddiff


********************************************************************************************************************
*** a. Weighted analyses ***

*** It is necessary for the check for confidentiality to always add the unweighted results when weighted
*** results are generated.

*** Output No. 3a: Unweighted frequencies for the federal state

tabulate EF1


*** Output No. 3b: Weighted frequencies for the federal state

tabulate EF1 [iw = EF952]


*** Output No. 4a: Unweighted regression using the dependent variable age (EF44) and
***                the dependend variables sex (EF46) and married (marr)

reg EF44 EF46 marr


*** Output No. 4b: Weighted regression using the dependent variable age (EF44) and
***                the dependend variables sex (EF46) and married (marr)

reg EF44 EF46 marr [aweight = EF952]


********************************************************************************************************************
*** b. Analyses using filter conditions ***

*** Remaining samples that contain the difference to the "total" value are to be avoided.
*** Example: You generate a "total" table and a "male" table.
*** The remaining sample/difference is "female". It has to be generated as well. 

*** Output No. 5a: Frequency of the highest qualification by total

tabulate EF310


*** Output No. 5b: Frequency of the highest qualification by male

tabulate EF310 if EF46 == 1


*** Output No. 5c: Frequency of the highest qualification by female

tabulate EF310 if EF46 == 2 


*** Note: Alternatively, a cross table without a previous case selection can be used for this kind of analysis.
*** By generating a cross table, remaining samples are avoided.


********************************************************************************************************************
*** c. Output of descriptive coefficients ***

*** For reasons of confidentiality, minima and maxima of metric variables are to be suppressed. 
*** The use of the tabulate-command is to be avoided when outputting descriptive key figures.

*** Output No. 6: Number of cases, mean and standard deviation for age of all single persons  (EF49==1)

*** Option 1: Use of the tabstat-command

tabstat EF44 if EF49 == 1, statistics(n mean sd) 


*** Option 2: Use of the sum-command
*** When using the sum-command you need to rewrite the sum-command. The use of the option detail is to be
*** avoided. Beforehand, the ado-file "makematrix.ado" has to be loaded.

makematrix, from(r(N) r(mean) r(sd)): sum EF44 if EF49 == 1


*** Note: For economic statistics, when generating descriptive coefficients the largest and next to largest value and the sum of all
*** values of the concerned variable (e.g. volume of sales, income) are to be stated. They are needed for the check for confidentiality.


********************************************************************************************************************
*** d. Output of dummy variables ***

*** In addition to the sum-command, a frequency table is to be produced because the number of cases is needed
*** for the check for confidentiality.
 
*** Output No. 7a:  Number of cases, mean and standard deviation for sex of all persons aged older than 65 (EF44 > 65)

summarize EF46 if EF44 > 65


*** Output No. 7b: Frequency table of sex of all persons aged older than 65 (EF44 > 65)

tabulate EF46 if EF44 > 65


********************************************************************************************************************
*** e. Output of value tables ***

*** When generating value tables, the corresponding cases of numbers always have to be stated as well.

*** Generation of a user-defined table with number of cases, mean and valid frequency (N) of age (EF44) by
*** class of marital status (EF49)

*** Output No. 8: Cross table age and marital status

tabstat EF44, statistics(mean count) by (EF49)


********************************************************************************************************************

*** The sample program code at hand illustrates an example for an initial program code. If analyses are executed in  
*** subsequent program codes and these analyses have a content-related connection to already generates results, these  
*** connections are to be marked with a comment when processing the data and when the analysis is being commanded.

********************************************************************************************************************
********************************************************************************************************************

log close

exit




